@@ -26,7 +26,6 @@
 #include <tuple>
 #include <utility>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/random/bit_gen_ref.h"
 #include "absl/random/random.h"
@@ -46,13 +45,14 @@
 #include "src/core/lib/resource_quota/resource_quota.h"
 #include "src/core/lib/slice/slice_buffer.h"
 #include "src/core/lib/transport/promise_endpoint.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/ref_counted_ptr.h"
 
 namespace grpc_core {
 namespace chaotic_good {
 
 ChaoticGoodClientTransport::StreamDispatch::StreamDispatch(
-    MpscSender<Frame> outgoing_frames)
+    MpscSender<OutgoingFrame> outgoing_frames)
     : outgoing_frames_(std::move(outgoing_frames)) {}
 
 RefCountedPtr<ChaoticGoodClientTransport::Stream>
@@ -67,7 +67,7 @@ ChaoticGoodClientTransport::StreamDispatch::LookupStream(uint32_t stream_id) {
 
 auto ChaoticGoodClientTransport::StreamDispatch::PushFrameIntoCall(
     ServerInitialMetadataFrame frame, RefCountedPtr<Stream> stream) {
-  DCHECK(stream->message_reassembly.in_message_boundary());
+  GRPC_DCHECK(stream->message_reassembly.in_message_boundary());
   auto headers = ServerMetadataGrpcFromProto(frame.body);
   if (!headers.ok()) {
     LOG_EVERY_N_SEC(INFO, 10) << "Encode headers failed: " << headers.status();
@@ -119,20 +119,21 @@ void ChaoticGoodClientTransport::StreamDispatch::DispatchFrame(
     IncomingFrame incoming_frame) {
   auto stream = LookupStream(incoming_frame.header().stream_id);
   if (stream == nullptr) return;
-  stream->frame_dispatch_serializer->Spawn(
-      [stream = std::move(stream),
-       incoming_frame = std::move(incoming_frame)]() mutable {
-        return Map(stream->call.CancelIfFails(TrySeq(
-                       incoming_frame.Payload(),
-                       [stream = std::move(stream)](Frame frame) mutable {
-                         auto& call = stream->call;
-                         return Map(call.CancelIfFails(PushFrameIntoCall(
-                                        std::move(std::get<T>(frame)),
-                                        std::move(stream))),
-                                    [](auto) { return absl::OkStatus(); });
-                       })),
-                   [](auto) {});
-      });
+  auto dispatcher = stream->frame_dispatch_serializer;
+  dispatcher->Spawn([stream,
+                     incoming_frame = std::move(incoming_frame)]() mutable {
+    auto& call = stream->call;
+    return Map(call.CancelIfFails(TrySeq(
+                   incoming_frame.Payload(),
+                   [stream = std::move(stream)](Frame frame) mutable {
+                     auto& call = stream->call;
+                     return Map(
+                         call.CancelIfFails(PushFrameIntoCall(
+                             std::move(std::get<T>(frame)), std::move(stream))),
+                         [](auto) { return absl::OkStatus(); });
+                   })),
+               [](auto) {});
+  });
 }
 
 void ChaoticGoodClientTransport::StreamDispatch::OnIncomingFrame(
@@ -160,8 +161,10 @@ void ChaoticGoodClientTransport::StreamDispatch::OnIncomingFrame(
 }
 
 void ChaoticGoodClientTransport::StreamDispatch::OnFrameTransportClosed(
-    absl::Status) {
+    absl::Status status) {
   // Mark transport as unavailable when the endpoint write/read failed.
+  GRPC_TRACE_LOG(chaotic_good, INFO)
+      << "CHAOTIC_GOOD: OnFrameTransportClosed: " << status;
   ReleasableMutexLock lock(&mu_);
   StreamMap stream_map = std::move(stream_map_);
   stream_map_.clear();
@@ -192,7 +195,7 @@ uint32_t ChaoticGoodClientTransport::StreamDispatch::MakeStream(
             << " done: cancelled=" << cancelled;
         if (cancelled) {
           self->outgoing_frames_.UnbufferedImmediateSend(
-              CancelFrame{stream_id});
+              UntracedOutgoingFrame(CancelFrame{stream_id}), 1);
         }
         MutexLock lock(&self->mu_);
         self->stream_map_.erase(stream_id);
@@ -219,28 +222,33 @@ void ChaoticGoodClientTransport::StreamDispatch::StopConnectivityWatch(
 ChaoticGoodClientTransport::ChaoticGoodClientTransport(
     const ChannelArgs& args, OrphanablePtr<FrameTransport> frame_transport,
     MessageChunker message_chunker)
-    : event_engine_(
-          args.GetObjectRef<grpc_event_engine::experimental::EventEngine>()),
+    : channelz::DataSource(frame_transport->ctx()->socket_node),
+      ctx_(frame_transport->ctx()),
       allocator_(args.GetObject<ResourceQuota>()
                      ->memory_quota()
                      ->CreateMemoryAllocator("chaotic-good")),
       message_chunker_(message_chunker),
       frame_transport_(std::move(frame_transport)) {
+  GRPC_CHECK(ctx_ != nullptr);
   auto party_arena = SimpleArenaAllocator(0)->MakeArena();
   party_arena->SetContext<grpc_event_engine::experimental::EventEngine>(
-      event_engine_.get());
+      ctx_->event_engine.get());
   party_ = Party::Make(std::move(party_arena));
-  MpscReceiver<Frame> outgoing_frames{8};
+  MpscReceiver<OutgoingFrame> outgoing_frames{256 * 1024 * 1024};
   outgoing_frames_ = outgoing_frames.MakeSender();
   stream_dispatch_ =
       MakeRefCounted<StreamDispatch>(outgoing_frames.MakeSender());
   frame_transport_->Start(party_.get(), std::move(outgoing_frames),
                           stream_dispatch_);
+  SourceConstructed();
 }
 
-ChaoticGoodClientTransport::~ChaoticGoodClientTransport() { party_.reset(); }
+ChaoticGoodClientTransport::~ChaoticGoodClientTransport() {
+  GRPC_DCHECK(party_.get() == nullptr);
+}
 
 void ChaoticGoodClientTransport::Orphan() {
+  SourceDestructing();
   stream_dispatch_->OnFrameTransportClosed(
       absl::UnavailableError("Transport closed"));
   party_.reset();
@@ -248,15 +256,31 @@ void ChaoticGoodClientTransport::Orphan() {
   Unref();
 }
 
+void ChaoticGoodClientTransport::AddData(channelz::DataSink sink) {
+  // TODO(ctiller): add calls in stream dispatch
+  party_->ExportToChannelz("transport_party", sink);
+}
+
 auto ChaoticGoodClientTransport::CallOutboundLoop(uint32_t stream_id,
                                                   CallHandler call_handler) {
-  auto send_fragment = [this, stream_id](auto frame) mutable {
+  CallTracer* const tracer = call_handler.arena()->GetContext<CallTracer>();
+  std::shared_ptr<TcpCallTracer> call_tracer;
+  if (tracer != nullptr && tracer->IsSampled()) {
+    call_tracer = tracer->StartNewTcpTrace();
+  }
+  auto send_fragment = [this, call_tracer, stream_id](auto frame) mutable {
     frame.stream_id = stream_id;
-    return outgoing_frames_.Send(std::move(frame));
+    auto tokens = FrameMpscTokens(frame);
+    return outgoing_frames_.Send(OutgoingFrame{std::move(frame), call_tracer},
+                                 tokens);
   };
-  auto send_message = [this, stream_id, message_chunker = message_chunker_](
-                          MessageHandle message) mutable {
-    return message_chunker.Send(std::move(message), stream_id,
+  auto send_message = [this, stream_id, call_tracer,
+                       message_chunker =
+                           message_chunker_](MessageHandle message) mutable {
+    if (ctx_->socket_node != nullptr) {
+      ctx_->socket_node->RecordMessagesSent(1);
+    }
+    return message_chunker.Send(std::move(message), stream_id, call_tracer,
                                 outgoing_frames_);
   };
   return GRPC_LATENT_SEE_PROMISE(
@@ -305,7 +329,10 @@ void ChaoticGoodClientTransport::StartCall(CallHandler call_handler) {
                       GRPC_TRACE_LOG(chaotic_good, INFO)
                           << "CHAOTIC_GOOD: Send cancel";
                       if (!self->outgoing_frames_
-                               .UnbufferedImmediateSend(CancelFrame{stream_id})
+                               .UnbufferedImmediateSend(
+                                   UntracedOutgoingFrame(
+                                       CancelFrame{stream_id}),
+                                   1)
                                .ok()) {
                         GRPC_TRACE_LOG(chaotic_good, INFO)
                             << "CHAOTIC_GOOD: Send cancel failed";
