@@ -16,27 +16,24 @@
 
 #include "src/core/xds/grpc/xds_cluster_specifier_plugin.h"
 
+#include <grpc/support/json.h>
+#include <grpc/support/port_platform.h>
 #include <stddef.h>
 
 #include <map>
 #include <utility>
+#include <variant>
 
-#include "absl/log/check.h"
 #include "absl/status/statusor.h"
 #include "absl/strings/str_cat.h"
-#include "absl/types/variant.h"
-#include "upb/base/status.hpp"
-#include "upb/json/encode.h"
-#include "upb/mem/arena.hpp"
-
-#include <grpc/support/json.h>
-#include <grpc/support/log.h>
-#include <grpc/support/port_platform.h>
-
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/json/json.h"
 #include "src/core/util/json/json_reader.h"
 #include "src/proto/grpc/lookup/v1/rls_config.upb.h"
 #include "src/proto/grpc/lookup/v1/rls_config.upbdefs.h"
+#include "upb/base/status.hpp"
+#include "upb/json/encode.h"
+#include "upb/mem/arena.hpp"
 
 namespace grpc_core {
 
@@ -58,7 +55,7 @@ Json XdsRouteLookupClusterSpecifierPlugin::GenerateLoadBalancingPolicyConfig(
     XdsExtension extension, upb_Arena* arena, upb_DefPool* symtab,
     ValidationErrors* errors) const {
   absl::string_view* serialized_plugin_config =
-      absl::get_if<absl::string_view>(&extension.value);
+      std::get_if<absl::string_view>(&extension.value);
   if (serialized_plugin_config == nullptr) {
     errors->AddError("could not parse plugin config");
     return {};
@@ -92,7 +89,7 @@ Json XdsRouteLookupClusterSpecifierPlugin::GenerateLoadBalancingPolicyConfig(
   upb_JsonEncode(plugin_config, msg_type, symtab, 0,
                  reinterpret_cast<char*>(buf), json_size + 1, status.ptr());
   auto json = JsonParse(reinterpret_cast<char*>(buf));
-  CHECK(json.ok());
+  GRPC_CHECK(json.ok());
   return Json::FromArray({Json::FromObject(
       {{"rls_experimental",
         Json::FromObject({
@@ -132,8 +129,8 @@ XdsClusterSpecifierPluginRegistry::GetPluginForType(
 
 void XdsClusterSpecifierPluginRegistry::PopulateSymtab(
     upb_DefPool* symtab) const {
-  for (const auto& p : registry_) {
-    p.second->PopulateSymtab(symtab);
+  for (const auto& [_, plugin] : registry_) {
+    plugin->PopulateSymtab(symtab);
   }
 }
 
