@@ -124,12 +124,45 @@ class BuildProjectMetadata(setuptools.Command):
         pass
 
     def run(self):
-        with open(
-            os.path.join(PYTHON_STEM, "grpc/_grpcio_metadata.py"), "w"
-        ) as module_file:
-            module_file.write(
-                '__version__ = """{}"""'.format(self.distribution.get_version())
-            )
+        module_file_path = os.path.join(PYTHON_STEM, "grpc/_grpcio_metadata.py")
+        version = self.distribution.get_version()
+
+        # TODO(sergiitk): sometime in Nov 2025 - consider removing the env var
+        # and making this the default behavior.
+        skip_metadata_update_on_match = os.environ.get(
+            "GRPC_PYTHON_BUILD_SKIP_METADATA_ON_VERSION_MATCH", "0"
+        )
+        if skip_metadata_update_on_match == "1":
+            with open(module_file_path, "r") as module_file:
+                # prevent replacing the copyright header
+                if self._get_version_in_grpcio_metadata(module_file) == version:
+                    print(
+                        f"Version match in _grpcio_metadata.py: {version},"
+                        " skipping the update"
+                    )
+                    return
+
+        with open(module_file_path, "w") as module_file:
+            module_file.write(f'__version__ = """{version}"""')
+
+    def _get_version_in_grpcio_metadata(self, module_file):
+        try:
+            import ast
+
+            tree = ast.parse(module_file.read())
+            for node in ast.walk(tree):
+                if isinstance(node, ast.Assign):
+                    for target in node.targets:
+                        if isinstance(target, ast.Name):
+                            variable_name = target.id
+                            if variable_name != "__version__":
+                                continue
+                            if isinstance(node.value, ast.Constant):
+                                return node.value.value
+        except:
+            raise
+
+        return "-1"
 
 
 class BuildPy(build_py.build_py):
@@ -248,53 +281,31 @@ class BuildExt(build_ext.build_ext):
         return filename
 
     def build_extensions(self):
-        def compiler_ok_with_extra_std():
-            """Test if default compiler is okay with specifying c++ version
-            when invoked in C mode. GCC is okay with this, while clang is not.
-            """
-            try:
-                # TODO(lidiz) Remove the generated a.out for success tests.
-                cc = os.environ.get("CC", "cc")
-                cc_test = subprocess.Popen(
-                    [cc, "-x", "c", "-std=c++14", "-"],
-                    stdin=subprocess.PIPE,
-                    stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE,
-                )
-                _, cc_err = cc_test.communicate(input=b"int main(){return 0;}")
-                return not "invalid argument" in str(cc_err)
-            except:
-                sys.stderr.write(
-                    "Non-fatal exception:" + traceback.format_exc() + "\n"
-                )
-                return False
+        # This is to let UnixCompiler get either C or C++ compiler options depending on the source.
+        # Note that this doesn't work for MSVCCompiler and will be handled by _spawn_patch.py.
+        old_compile = self.compiler._compile
 
-        # This special conditioning is here due to difference of compiler
-        #   behavior in gcc and clang. The clang doesn't take --stdc++11
-        #   flags but gcc does. Since the setuptools of Python only support
-        #   all C or all C++ compilation, the mix of C and C++ will crash.
-        #   *By default*, macOS and FreeBSD use clang and Linux use gcc
-        #
-        #   If we are not using a permissive compiler that's OK with being
-        #   passed wrong std flags, swap out compile function by adding a filter
-        #   for it.
-        if not compiler_ok_with_extra_std():
-            old_compile = self.compiler._compile
+        def new_compile(obj, src, ext, cc_args, extra_postargs, pp_opts):
+            # NOTE: keep in sync with setup.py EXTRA_ENV_COMPILE_ARGS.
+            cpp_specific_args = {"-std=c++17", "-stdlib=libc++"}
+            c_specific_args = {"-std=c11"}
 
-            def new_compile(obj, src, ext, cc_args, extra_postargs, pp_opts):
-                if src.endswith(".c"):
-                    extra_postargs = [
-                        arg for arg in extra_postargs if "-std=c++" not in arg
-                    ]
-                elif src.endswith(".cc") or src.endswith(".cpp"):
-                    extra_postargs = [
-                        arg for arg in extra_postargs if "-std=gnu99" not in arg
-                    ]
-                return old_compile(
-                    obj, src, ext, cc_args, extra_postargs, pp_opts
-                )
+            args_to_remove = set()
+            if src.endswith(".c"):
+                # Remove cpp-specific args when compiling c.
+                args_to_remove = cpp_specific_args
+            elif src.endswith((".cc", ".cpp")):
+                # Remove c-specific args when compiling c++.
+                args_to_remove = c_specific_args
 
-            self.compiler._compile = new_compile
+            if args_to_remove:
+                extra_postargs = [
+                    arg for arg in extra_postargs if arg not in args_to_remove
+                ]
+
+            return old_compile(obj, src, ext, cc_args, extra_postargs, pp_opts)
+
+        self.compiler._compile = new_compile
 
         compiler = self.compiler.compiler_type
         if compiler in BuildExt.C_OPTIONS:
