@@ -88,15 +88,17 @@ void PythonLabelsInjector::AddXdsOptionalLabels(
   // Performs JSON label name format to CSM Observability Metric spec format
   // conversion.
   absl::string_view service_name =
-      optional_labels_span[static_cast<size_t>(
-                               grpc_core::ClientCallTracer::CallAttemptTracer::
-                                   OptionalLabelKey::kXdsServiceName)]
-          .as_string_view();
+      optional_labels_span
+          [static_cast<size_t>(
+               grpc_core::ClientCallTracerInterface::CallAttemptTracer::
+                   OptionalLabelKey::kXdsServiceName)]
+              .as_string_view();
   absl::string_view service_namespace =
-      optional_labels_span[static_cast<size_t>(
-                               grpc_core::ClientCallTracer::CallAttemptTracer::
-                                   OptionalLabelKey::kXdsServiceNamespace)]
-          .as_string_view();
+      optional_labels_span
+          [static_cast<size_t>(
+               grpc_core::ClientCallTracerInterface::CallAttemptTracer::
+                   OptionalLabelKey::kXdsServiceNamespace)]
+              .as_string_view();
   // According to the CSM Observability Metric spec, if the control plane fails
   // to provide these labels, the client will set their values to "unknown".
   if (service_name.empty()) {
