@@ -15,10 +15,6 @@
 #ifndef GRPC_TEST_CORE_END2END_FIXTURES_H2_SSL_TLS_COMMON_H
 #define GRPC_TEST_CORE_END2END_FIXTURES_H2_SSL_TLS_COMMON_H
 
-#include <string.h>
-
-#include "absl/log/check.h"
-
 #include <grpc/credentials.h>
 #include <grpc/grpc.h>
 #include <grpc/grpc_security.h>
@@ -26,10 +22,12 @@
 #include <grpc/impl/channel_arg_names.h>
 #include <grpc/slice.h>
 #include <grpc/status.h>
+#include <string.h>
 
+#include "src/core/credentials/transport/ssl/ssl_credentials.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/iomgr/error.h"
-#include "src/core/lib/security/credentials/ssl/ssl_credentials.h"
+#include "src/core/util/grpc_check.h"
 #include "test/core/end2end/end2end_tests.h"
 #include "test/core/end2end/fixtures/secure_fixture.h"
 #include "test/core/test_util/tls_utils.h"
@@ -47,7 +45,7 @@ class SslTlsFixture : public SecureFixture {
     return "src/core/tsi/test_creds/server1.key";
   }
 
- private:
+ protected:
   grpc_core::ChannelArgs MutateClientArgs(
       grpc_core::ChannelArgs args) override {
     return args.Set(GRPC_SSL_TARGET_NAME_OVERRIDE_ARG, "foo.test.google.fr");
@@ -92,16 +90,22 @@ class SslTlsFixture : public SecureFixture {
     return ssl_creds;
   }
 
+ private:
   static void process_auth_failure(void* state, grpc_auth_context* /*ctx*/,
                                    const grpc_metadata* /*md*/,
                                    size_t /*md_count*/,
                                    grpc_process_auth_metadata_done_cb cb,
                                    void* user_data) {
-    CHECK_EQ(state, nullptr);
+    GRPC_CHECK_EQ(state, nullptr);
     cb(user_data, nullptr, 0, nullptr, 0, GRPC_STATUS_UNAUTHENTICATED, nullptr);
   }
 
   grpc_tls_version tls_version_;
 };
 
+class SslTlsFixture1_3 : public SslTlsFixture {
+ public:
+  SslTlsFixture1_3() : SslTlsFixture(grpc_tls_version::TLS1_3) {}
+};
+
 #endif  // GRPC_TEST_CORE_END2END_FIXTURES_H2_SSL_TLS_COMMON_H
