@@ -16,15 +16,15 @@
 #include <grpc/impl/channel_arg_names.h>
 #include <grpc/slice.h>
 
+#include <optional>
 #include <string>
 
-#include "absl/log/check.h"
 #include "absl/status/statusor.h"
-#include "absl/types/optional.h"
+#include "fuzztest/fuzztest.h"
+#include "src/core/config/core_configuration.h"
 #include "src/core/ext/transport/chttp2/transport/chttp2_transport.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/channel/channel_args_preconditioning.h"
-#include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/experiments/config.h"
 #include "src/core/lib/iomgr/endpoint.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
@@ -33,14 +33,15 @@
 #include "src/core/lib/surface/channel_stack_type.h"
 #include "src/core/lib/transport/transport.h"
 #include "src/core/util/env.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/orphanable.h"
 #include "src/core/util/ref_counted_ptr.h"
-#include "src/libfuzzer/libfuzzer_macro.h"
 #include "test/core/end2end/fuzzers/api_fuzzer.pb.h"
 #include "test/core/end2end/fuzzers/fuzzer_input.pb.h"
 #include "test/core/end2end/fuzzers/fuzzing_common.h"
 #include "test/core/end2end/fuzzers/network_input.h"
 #include "test/core/test_util/fuzz_config_vars.h"
+#include "test/core/test_util/fuzz_config_vars_helpers.h"
 #include "test/core/test_util/mock_endpoint.h"
 #include "test/core/test_util/test_config.h"
 
@@ -78,7 +79,7 @@ class ClientFuzzer final : public BasicFuzzer {
                    ->c_ptr();
   }
 
-  ~ClientFuzzer() { CHECK_EQ(channel_, nullptr); }
+  ~ClientFuzzer() { GRPC_CHECK_EQ(channel_, nullptr); }
 
  private:
   Result CreateChannel(const api_fuzzer::CreateChannel&) override {
@@ -101,15 +102,18 @@ class ClientFuzzer final : public BasicFuzzer {
   grpc_channel* channel_ = nullptr;
 };
 
-}  // namespace testing
-}  // namespace grpc_core
-
-DEFINE_PROTO_FUZZER(const fuzzer_input::Msg& msg) {
-  if (squelch && !grpc_core::GetEnv("GRPC_TRACE_FUZZER").has_value()) {
+void Run(fuzzer_input::Msg msg) {
+  if (squelch && !GetEnv("GRPC_TRACE_FUZZER").has_value()) {
     grpc_disable_all_absl_logs();
   }
   if (msg.network_input().size() != 1) return;
-  grpc_core::ApplyFuzzConfigVars(msg.config_vars());
-  grpc_core::TestOnlyReloadExperimentsFromConfigVariables();
-  grpc_core::testing::ClientFuzzer(msg).Run(msg.api_actions());
+  ApplyFuzzConfigVars(msg.config_vars());
+  TestOnlyReloadExperimentsFromConfigVariables();
+  testing::ClientFuzzer(msg).Run(msg.api_actions());
 }
+FUZZ_TEST(ClientFuzzerTest, Run)
+    .WithDomains(::fuzztest::Arbitrary<fuzzer_input::Msg>().WithProtobufField(
+        "config_vars", AnyConfigVars()));
+
+}  // namespace testing
+}  // namespace grpc_core
