@@ -20,16 +20,17 @@
 #include <optional>
 #include <string>
 
-#include "absl/log/check.h"
 #include "fuzztest/fuzztest.h"
 #include "gtest/gtest.h"
 #include "src/core/config/core_configuration.h"
+#include "src/core/credentials/transport/fake/fake_credentials.h"
 #include "src/core/ext/transport/chaotic_good/server/chaotic_good_server.h"
 #include "src/core/lib/event_engine/tcp_socket_utils.h"
 #include "src/core/lib/experiments/config.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
-#include "src/core/lib/security/credentials/fake/fake_credentials.h"
 #include "src/core/util/env.h"
+#include "src/core/util/grpc_check.h"
+#include "src/core/util/notification.h"
 #include "test/core/end2end/fuzzers/api_fuzzer.pb.h"
 #include "test/core/end2end/fuzzers/fuzzer_input.pb.h"
 #include "test/core/end2end/fuzzers/fuzzing_common.h"
@@ -41,11 +42,14 @@
 namespace grpc_core {
 namespace testing {
 
+using grpc_event_engine::experimental::FuzzingEventEngine;
+
 class ServerFuzzer final : public BasicFuzzer {
  public:
   explicit ServerFuzzer(
       const fuzzer_input::Msg& msg,
-      absl::FunctionRef<void(grpc_server*, int, const ChannelArgs&)>
+      absl::FunctionRef<void(FuzzingEventEngine*, grpc_server*, int,
+                             const ChannelArgs&)>
           server_setup)
       : BasicFuzzer(msg.event_engine_actions()) {
     ExecCtx exec_ctx;
@@ -53,7 +57,7 @@ class ServerFuzzer final : public BasicFuzzer {
     // TODO(ctiller): add more registered methods (one for POST, one for PUT)
     grpc_server_register_method(server_, "/reg", nullptr, {}, 0);
     server_setup(
-        server_, 1234,
+        engine().get(), server_, 1234,
         CoreConfiguration::Get()
             .channel_args_preconditioning()
             .PreconditionChannelArgs(
@@ -68,7 +72,7 @@ class ServerFuzzer final : public BasicFuzzer {
     }
   }
 
-  ~ServerFuzzer() { CHECK_EQ(server_, nullptr); }
+  ~ServerFuzzer() { GRPC_CHECK_EQ(server_, nullptr); }
 
  private:
   Result CreateChannel(
@@ -91,16 +95,13 @@ class ServerFuzzer final : public BasicFuzzer {
   grpc_server* server_ = grpc_server_create(nullptr, nullptr);
 };
 
-void RunServerFuzzer(
-    const fuzzer_input::Msg& msg,
-    absl::FunctionRef<void(grpc_server*, int, const ChannelArgs&)>
-        server_setup) {
-  static const int once = []() {
-    ForceEnableExperiment("event_engine_client", true);
-    ForceEnableExperiment("event_engine_listener", true);
-    return 42;
-  }();
-  CHECK_EQ(once, 42);  // avoid unused variable warning
+void RunServerFuzzer(const fuzzer_input::Msg& msg,
+                     absl::FunctionRef<void(FuzzingEventEngine*, grpc_server*,
+                                            int, const ChannelArgs&)>
+                         server_setup) {
+  if (!IsEventEngineClientEnabled() || !IsEventEngineListenerEnabled()) {
+    return;  // Not supported without event engine
+  }
   ApplyFuzzConfigVars(msg.config_vars());
   TestOnlyReloadExperimentsFromConfigVariables();
   testing::ServerFuzzer(msg, server_setup).Run(msg.api_actions());
@@ -108,13 +109,13 @@ void RunServerFuzzer(
 
 auto ParseTestProto(const std::string& proto) {
   fuzzer_input::Msg msg;
-  CHECK(google::protobuf::TextFormat::ParseFromString(proto, &msg));
+  GRPC_CHECK(google::protobuf::TextFormat::ParseFromString(proto, &msg));
   return msg;
 }
 
 void ChaoticGood(fuzzer_input::Msg msg) {
-  RunServerFuzzer(msg, [](grpc_server* server, int port_num,
-                          const ChannelArgs& channel_args) {
+  RunServerFuzzer(msg, [](FuzzingEventEngine* engine, grpc_server* server,
+                          int port_num, const ChannelArgs& channel_args) {
     ExecCtx exec_ctx;
     auto* listener = new chaotic_good::ChaoticGoodServerListener(
         Server::FromC(server), channel_args, [next = uint64_t(0)]() mutable {
@@ -124,8 +125,8 @@ void ChaoticGood(fuzzer_input::Msg msg) {
         listener->Bind(grpc_event_engine::experimental::URIToResolvedAddress(
                            absl::StrCat("ipv4:0.0.0.0:", port_num))
                            .value());
-    CHECK_OK(port);
-    CHECK_EQ(port.value(), port_num);
+    GRPC_CHECK_OK(port);
+    GRPC_CHECK_EQ(port.value(), port_num);
     Server::FromC(server)->AddListener(
         OrphanablePtr<chaotic_good::ChaoticGoodServerListener>(listener));
   });
@@ -135,26 +136,40 @@ FUZZ_TEST(ServerFuzzers, ChaoticGood)
         "config_vars", AnyConfigVars()));
 
 void Chttp2(fuzzer_input::Msg msg) {
-  RunServerFuzzer(
-      msg, [](grpc_server* server, int port_num, const ChannelArgs&) {
-        auto* creds = grpc_insecure_server_credentials_create();
-        grpc_server_add_http2_port(
-            server, absl::StrCat("0.0.0.0:", port_num).c_str(), creds);
-        grpc_server_credentials_release(creds);
-      });
+  RunServerFuzzer(msg, [](FuzzingEventEngine* engine, grpc_server* server,
+                          int port_num, const ChannelArgs&) {
+    auto* creds = grpc_insecure_server_credentials_create();
+    Notification done_adding_port;
+    engine->Run([&]() {
+      grpc_server_add_http2_port(
+          server, absl::StrCat("0.0.0.0:", port_num).c_str(), creds);
+      done_adding_port.Notify();
+    });
+    while (!done_adding_port.HasBeenNotified()) {
+      engine->Tick(Duration::Seconds(1));
+    };
+    grpc_server_credentials_release(creds);
+  });
 }
 FUZZ_TEST(ServerFuzzers, Chttp2)
     .WithDomains(::fuzztest::Arbitrary<fuzzer_input::Msg>().WithProtobufField(
         "config_vars", AnyConfigVars()));
 
 void Chttp2FakeSec(fuzzer_input::Msg msg) {
-  RunServerFuzzer(
-      msg, [](grpc_server* server, int port_num, const ChannelArgs&) {
-        auto* creds = grpc_fake_transport_security_server_credentials_create();
-        grpc_server_add_http2_port(
-            server, absl::StrCat("0.0.0.0:", port_num).c_str(), creds);
-        grpc_server_credentials_release(creds);
-      });
+  RunServerFuzzer(msg, [](FuzzingEventEngine* engine, grpc_server* server,
+                          int port_num, const ChannelArgs&) {
+    auto* creds = grpc_fake_transport_security_server_credentials_create();
+    Notification done_adding_port;
+    engine->Run([&]() {
+      grpc_server_add_http2_port(
+          server, absl::StrCat("0.0.0.0:", port_num).c_str(), creds);
+      done_adding_port.Notify();
+    });
+    while (!done_adding_port.HasBeenNotified()) {
+      engine->Tick(Duration::Seconds(1));
+    }
+    grpc_server_credentials_release(creds);
+  });
 }
 FUZZ_TEST(ServerFuzzers, Chttp2FakeSec)
     .WithDomains(::fuzztest::Arbitrary<fuzzer_input::Msg>().WithProtobufField(
@@ -305,5 +320,21 @@ TEST(ServerFuzzers, ChaoticGoodRegression2) {
       )pb"));
 }
 
+TEST(ServerFuzzers, ChaoticGoodRegression3) {
+  ChaoticGood(ParseTestProto(
+      R"pb(network_input {
+             connect_timeout_ms: 2147483647
+             endpoint_config { args { resource_quota {} } }
+           }
+           api_actions { post_mortem_emit {} }
+           event_engine_actions {
+             run_delay: 18446744073709551615
+             assign_ports: 4294967295
+             endpoint_metrics { key: 2147483647 name: "\362\241\213\224" }
+           }
+           shutdown_connector { delay_ms: 1 }
+      )pb"));
+}
+
 }  // namespace testing
 }  // namespace grpc_core
