@@ -136,7 +136,7 @@ class TestState {
       ABSL_GUARDED_BY(mu_);
 };
 
-class FakeCallTracer : public ClientCallTracer {
+class FakeCallTracer : public ClientCallTracerInterface {
  public:
   class FakeCallAttemptTracer : public CallAttemptTracer {
    public:
@@ -191,7 +191,7 @@ class FakeCallTracer : public ClientCallTracer {
     std::shared_ptr<TcpCallTracer> StartNewTcpTrace() override {
       return nullptr;
     }
-    void RecordEnd(const gpr_timespec& /*latency*/) override {
+    void RecordEnd() override {
       test_state_->NotifyClient();
       delete this;
     }
@@ -224,7 +224,7 @@ class FakeCallTracer : public ClientCallTracer {
   std::shared_ptr<TestState> test_state_;
 };
 
-class FakeServerCallTracer : public ServerCallTracer {
+class FakeServerCallTracer : public ServerCallTracerInterface {
  public:
   explicit FakeServerCallTracer(std::shared_ptr<TestState> test_state)
       : test_state_(test_state) {
@@ -288,12 +288,12 @@ class NewFakeStatsPlugin : public FakeStatsPlugin {
   explicit NewFakeStatsPlugin(std::shared_ptr<TestState> test_state)
       : test_state_(std::move(test_state)) {}
 
-  ClientCallTracer* GetClientCallTracer(
+  ClientCallTracerInterface* GetClientCallTracer(
       const Slice& /*path*/, bool /*registered_method*/,
       std::shared_ptr<StatsPlugin::ScopeConfig> /*scope_config*/) override {
     return GetContext<Arena>()->ManagedNew<FakeCallTracer>(test_state_);
   }
-  ServerCallTracer* GetServerCallTracer(
+  ServerCallTracerInterface* GetServerCallTracer(
       std::shared_ptr<StatsPlugin::ScopeConfig> /*scope_config*/) override {
     return GetContext<Arena>()->ManagedNew<FakeServerCallTracer>(test_state_);
   }
