@@ -27,7 +27,7 @@
 namespace grpc_core {
 namespace {
 
-CORE_END2END_TEST(CoreDeadlineTest, NegativeDeadline) {
+CORE_END2END_TEST(CoreDeadlineTests, NegativeDeadline) {
   auto c =
       NewClientCall("/service/method").Timeout(Duration::Seconds(-1)).Create();
   IncomingStatusOnClient server_status;
