@@ -12,35 +12,34 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#include <memory>
-
-#include "absl/functional/any_invocable.h"
-#include "absl/log/check.h"
-
 #include <grpc/event_engine/event_engine.h>
 #include <grpc/support/port_platform.h>
 
+#include <memory>
+
+#include "absl/functional/any_invocable.h"
 #include "src/core/lib/iomgr/port.h"
+#include "src/core/util/grpc_check.h"  // IWYU pragma: keep
 
 #ifdef GRPC_POSIX_SOCKET_TCP
 
 #include "src/core/lib/event_engine/posix_engine/posix_engine.h"
 
 absl::AnyInvocable<
-    std::unique_ptr<grpc_event_engine::experimental::EventEngine>(void)>
+    std::shared_ptr<grpc_event_engine::experimental::EventEngine>(void)>
 CustomEventEngineFactory() {
   return []() {
-    return std::make_unique<
-        grpc_event_engine::experimental::PosixEventEngine>();
+    return grpc_event_engine::experimental::PosixEventEngine::
+        MakePosixEventEngine();
   };
 }
 
 #else
 
 absl::AnyInvocable<
-    std::unique_ptr<grpc_event_engine::experimental::EventEngine>(void)>
+    std::shared_ptr<grpc_event_engine::experimental::EventEngine>(void)>
 CustomEventEngineFactory() {
-  CHECK(false) <<  "This tool was not built for Posix environments.");
+  GRPC_CHECK(false) <<  "This tool was not built for Posix environments.");
 }
 
 #endif
