@@ -14,21 +14,20 @@
 // limitations under the License.
 //
 
+#include <benchmark/benchmark.h>
+
 #include <algorithm>
 #include <atomic>
 #include <cstdint>
+#include <optional>
 #include <vector>
 
-#include <benchmark/benchmark.h>
-
 #include "absl/algorithm/container.h"
-#include "absl/log/check.h"
 #include "absl/random/random.h"
-#include "absl/types/optional.h"
 #include "absl/types/span.h"
-
-#include "src/core/lib/gprpp/no_destruct.h"
 #include "src/core/load_balancing/weighted_round_robin/static_stride_scheduler.h"
+#include "src/core/util/grpc_check.h"
+#include "src/core/util/no_destruct.h"
 
 namespace grpc_core {
 namespace {
@@ -57,11 +56,11 @@ const std::vector<float>& Weights() {
 
 void BM_StaticStrideSchedulerPickNonAtomic(benchmark::State& state) {
   uint32_t sequence = 0;
-  const absl::optional<StaticStrideScheduler> scheduler =
+  const std::optional<StaticStrideScheduler> scheduler =
       StaticStrideScheduler::Make(
           absl::MakeSpan(Weights()).subspan(0, state.range(0)),
           [&] { return sequence++; });
-  CHECK(scheduler.has_value());
+  GRPC_CHECK(scheduler.has_value());
   for (auto s : state) {
     benchmark::DoNotOptimize(scheduler->Pick());
   }
@@ -72,11 +71,11 @@ BENCHMARK(BM_StaticStrideSchedulerPickNonAtomic)
 
 void BM_StaticStrideSchedulerPickAtomic(benchmark::State& state) {
   std::atomic<uint32_t> sequence{0};
-  const absl::optional<StaticStrideScheduler> scheduler =
+  const std::optional<StaticStrideScheduler> scheduler =
       StaticStrideScheduler::Make(
           absl::MakeSpan(Weights()).subspan(0, state.range(0)),
           [&] { return sequence.fetch_add(1, std::memory_order_relaxed); });
-  CHECK(scheduler.has_value());
+  GRPC_CHECK(scheduler.has_value());
   for (auto s : state) {
     benchmark::DoNotOptimize(scheduler->Pick());
   }
@@ -88,11 +87,11 @@ BENCHMARK(BM_StaticStrideSchedulerPickAtomic)
 void BM_StaticStrideSchedulerMake(benchmark::State& state) {
   uint32_t sequence = 0;
   for (auto s : state) {
-    const absl::optional<StaticStrideScheduler> scheduler =
+    const std::optional<StaticStrideScheduler> scheduler =
         StaticStrideScheduler::Make(
             absl::MakeSpan(Weights()).subspan(0, state.range(0)),
             [&] { return sequence++; });
-    CHECK(scheduler.has_value());
+    GRPC_CHECK(scheduler.has_value());
   }
 }
 BENCHMARK(BM_StaticStrideSchedulerMake)
