@@ -23,18 +23,20 @@
 #include <string>
 #include <utility>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/strings/str_cat.h"
 #include "absl/time/time.h"
 #include "gmock/gmock.h"
 #include "gtest/gtest.h"
+#include "src/core/ext/transport/chaotic_good/chaotic_good.h"
 #include "src/core/ext/transport/chaotic_good/client/chaotic_good_connector.h"
 #include "src/core/lib/address_utils/parse_address.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/event_engine/default_event_engine.h"
 #include "src/core/lib/event_engine/tcp_socket_utils.h"
 #include "src/core/server/server.h"
+#include "src/core/transport/endpoint_transport.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/notification.h"
 #include "src/core/util/time.h"
 #include "src/core/util/uri.h"
@@ -71,8 +73,8 @@ class ChaoticGoodServerTest : public ::testing::Test {
     if (ev.type == GRPC_QUEUE_TIMEOUT) {
       AsanAssertNoLeaks();
     }
-    CHECK_EQ(ev.type, GRPC_OP_COMPLETE);
-    CHECK_EQ(ev.tag, nullptr);
+    GRPC_CHECK_EQ(ev.type, GRPC_OP_COMPLETE);
+    GRPC_CHECK_EQ(ev.tag, nullptr);
     grpc_completion_queue_destroy(shutdown_cq);
     grpc_server_destroy(server_);
   }
@@ -80,20 +82,27 @@ class ChaoticGoodServerTest : public ::testing::Test {
   void StartServer() {
     port_ = grpc_pick_unused_port_or_die();
     addr_ = absl::StrCat("[::1]:", port_);
-    server_ = grpc_server_create(nullptr, nullptr);
-    grpc_server_add_chaotic_good_port(server_, addr_.c_str());
+    server_ =
+        grpc_server_create(ChannelArgs()
+                               .Set(GRPC_ARG_PREFERRED_TRANSPORT_PROTOCOLS,
+                                    WireFormatPreferences())
+                               .ToC()
+                               .get(),
+                           nullptr);
+    auto* creds = grpc_insecure_server_credentials_create();
+    grpc_server_add_http2_port(server_, addr_.c_str(), creds);
+    grpc_server_credentials_release(creds);
     grpc_server_start(server_);
   }
 
   void ConstructConnector() {
     auto uri = URI::Parse("ipv6:" + addr_);
-    CHECK_OK(uri);
-    CHECK(grpc_parse_uri(*uri, &resolved_addr_));
+    GRPC_CHECK_OK(uri);
+    GRPC_CHECK(grpc_parse_uri(*uri, &resolved_addr_));
     args_.address = &resolved_addr_;
     args_.deadline = Timestamp::Now() + Duration::Seconds(5);
     args_.channel_args = channel_args();
-    connector_ = MakeRefCounted<ChaoticGoodConnector>(
-        grpc_event_engine::experimental::GetDefaultEventEngine());
+    connector_ = MakeRefCounted<ChaoticGoodConnector>();
   }
 
  protected:
@@ -124,6 +133,9 @@ class ChaoticGoodServerTest : public ::testing::Test {
 };
 
 TEST_F(ChaoticGoodServerTest, Connect) {
+  if (!IsChaoticGoodFramingLayerEnabled()) {
+    GTEST_SKIP() << "Chaotic Good framing layer is not enabled";
+  }
   GRPC_CLOSURE_INIT(&on_connecting_finished_, OnConnectingFinished, this,
                     grpc_schedule_on_exec_ctx);
   connector_->Connect(args_, &connecting_result_, &on_connecting_finished_);
@@ -131,6 +143,9 @@ TEST_F(ChaoticGoodServerTest, Connect) {
 }
 
 TEST_F(ChaoticGoodServerTest, ConnectAndShutdown) {
+  if (!IsChaoticGoodFramingLayerEnabled()) {
+    GTEST_SKIP() << "Chaotic Good framing layer is not enabled";
+  }
   Notification connect_finished;
   GRPC_CLOSURE_INIT(&on_connecting_finished_, OnConnectingFinished, this,
                     grpc_schedule_on_exec_ctx);
