@@ -18,17 +18,15 @@
 
 #include "src/core/tsi/alts/frame_protector/frame_handler.h"
 
+#include <grpc/support/alloc.h>
 #include <stdint.h>
 #include <stdio.h>
 #include <string.h>
 
 #include <algorithm>
 
-#include <gtest/gtest.h>
-
-#include <grpc/support/alloc.h>
-
-#include "src/core/lib/gprpp/crash.h"
+#include "gtest/gtest.h"
+#include "src/core/util/crash.h"
 #include "src/core/util/useful.h"
 #include "test/core/tsi/alts/crypt/gsec_test_util.h"
 
