@@ -18,17 +18,16 @@
 
 #include "test/cpp/interop/stress_interop_client.h"
 
+#include <grpcpp/create_channel.h>
+
 #include <memory>
 #include <string>
 #include <vector>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/strings/str_format.h"
-
-#include <grpcpp/create_channel.h>
-
-#include "src/core/lib/gprpp/crash.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/grpc_check.h"
 #include "test/cpp/interop/interop_client.h"
 #include "test/cpp/util/metrics_server.h"
 
@@ -66,7 +65,7 @@ TestCaseType WeightedRandomTestSelector::GetNextTest() const {
   }
 
   // It is a bug in the logic if no test is selected at this point
-  CHECK(selected_test != UNKNOWN_TEST);
+  GRPC_CHECK(selected_test != UNKNOWN_TEST);
   return selected_test;
 }
 
