@@ -16,23 +16,20 @@
 //
 //
 
+#include <benchmark/benchmark.h>
+#include <grpc/grpc.h>
+#include <grpc/support/alloc.h>
 #include <string.h>
 
 #include <atomic>
 
-#include <benchmark/benchmark.h>
-
-#include "absl/log/check.h"
 #include "absl/log/log.h"
-
-#include <grpc/grpc.h>
-#include <grpc/support/alloc.h>
-
-#include "src/core/lib/gprpp/crash.h"
-#include "src/core/lib/gprpp/time.h"
 #include "src/core/lib/iomgr/ev_posix.h"
 #include "src/core/lib/iomgr/port.h"
 #include "src/core/lib/surface/completion_queue.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/grpc_check.h"
+#include "src/core/util/time.h"
 #include "test/core/test_util/test_config.h"
 #include "test/cpp/microbenchmarks/helpers.h"
 #include "test/cpp/util/test_config.h"
@@ -84,7 +81,7 @@ static grpc_error_handle pollset_work(grpc_pollset* ps,
   gpr_mu_unlock(&ps->mu);
 
   void* tag = reinterpret_cast<void*>(10);  // Some random number
-  CHECK(grpc_cq_begin_op(g_cq, tag));
+  GRPC_CHECK(grpc_cq_begin_op(g_cq, tag));
   grpc_cq_end_op(
       g_cq, tag, absl::OkStatus(), cq_done_cb, nullptr,
       static_cast<grpc_cq_completion*>(gpr_malloc(sizeof(grpc_cq_completion))));
@@ -119,8 +116,9 @@ static grpc_event_engine_vtable make_engine_vtable(const char* name) {
 
 static void setup() {
   grpc_init();
-  CHECK(strcmp(grpc_get_poll_strategy_name(), "none") == 0 ||
-        strcmp(grpc_get_poll_strategy_name(), "bm_cq_multiple_threads") == 0);
+  GRPC_CHECK(strcmp(grpc_get_poll_strategy_name(), "none") == 0 ||
+             strcmp(grpc_get_poll_strategy_name(), "bm_cq_multiple_threads") ==
+                 0);
 
   g_cq = grpc_completion_queue_create_for_next(nullptr);
 }
@@ -177,8 +175,8 @@ static void BM_Cq_Throughput(benchmark::State& state) {
   gpr_mu_unlock(&g_mu);
 
   for (auto _ : state) {
-    CHECK(grpc_completion_queue_next(g_cq, deadline, nullptr).type ==
-          GRPC_OP_COMPLETE);
+    GRPC_CHECK(grpc_completion_queue_next(g_cq, deadline, nullptr).type ==
+               GRPC_OP_COMPLETE);
   }
 
   state.SetItemsProcessed(state.iterations());
