@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Generator script for src/core/lib/security/credentials/tls/grpc_tls_credentials_options.h and test/core/security/grpc_tls_credentials_options_comparator_test.cc
+# Generator script for src/core/credentials/transport/tls/grpc_tls_credentials_options.h and test/core/credentials/transport/tls/grpc_tls_credentials_options_comparator_test.cc
 # Should be executed from grpc's root directory.
 
 from __future__ import print_function
@@ -32,24 +32,28 @@ import tempfile
 class DataMember:
     name: str  # name of the data member without the trailing '_'
     type: str  # Type (eg. std::string, bool)
+
     test_name: str  # The name to use for the associated test
     test_value_1: str  # Test-specific value to use for comparison
     test_value_2: str  # Test-specific value (different from test_value_1)
-    default_initializer: str = (  # If non-empty, this will be used as the default initialization of this field
-        ""
-    )
-    getter_comment: str = ""  # Comment to add before the getter for this field
-    special_getter_return_type: str = (  # Override for the return type of getter (eg. const std::string&)
-        ""
-    )
-    override_getter: str = (  # Override for the entire getter method. Relevant for certificate_verifier and certificate_provider
-        ""
-    )
-    setter_comment: str = ""  # Commend to add before the setter for this field
+
+    # If non-empty, this will be used as the default initialization
+    # of this field.
+    default_initializer: str = ""
+
+    # Comment to add before the getter for this field
+    getter_comment: str = ""
+    # Override for the return type of getter (eg. const std::string&)
+    special_getter_return_type: str = ""
+    # Override for the entire getter method.
+    # Relevant for certificate_verifier and certificate_provider.
+    override_getter: str = ""
+
+    setter_comment: str = ""  # Comment to add before the setter for this field
     setter_move_semantics: bool = False  # Should the setter use move-semantics
-    special_comparator: str = (  # If non-empty, this will be used in `operator==`
-        ""
-    )
+
+    # If non-empty, this will be used in `operator==`
+    special_comparator: str = ""
 
 
 _DATA_MEMBERS = [
@@ -284,9 +288,9 @@ if len(sys.argv) > 1 and sys.argv[1] == "--test":
     test_mode = True
 
 HEADER_FILE_NAME = (
-    "src/core/lib/security/credentials/tls/grpc_tls_credentials_options.h"
+    "src/core/credentials/transport/tls/grpc_tls_credentials_options.h"
 )
-# Generate src/core/lib/security/credentials/tls/grpc_tls_credentials_options.h
+# Generate src/core/credentials/transport/tls/grpc_tls_credentials_options.h
 header_file_name = HEADER_FILE_NAME
 if test_mode:
     header_file_name = tempfile.NamedTemporaryFile(delete=False).name
@@ -298,8 +302,8 @@ print(
     file=H,
 )
 print(
-    """#ifndef GRPC_SRC_CORE_LIB_SECURITY_CREDENTIALS_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H
-#define GRPC_SRC_CORE_LIB_SECURITY_CREDENTIALS_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H
+    """#ifndef GRPC_SRC_CORE_CREDENTIALS_TRANSPORT_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H
+#define GRPC_SRC_CORE_CREDENTIALS_TRANSPORT_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H
 
 #include <grpc/support/port_platform.h>
 
@@ -308,11 +312,11 @@ print(
 #include <grpc/credentials.h>
 #include <grpc/grpc_security.h>
 
-#include "src/core/lib/gprpp/ref_counted.h"
-#include "src/core/lib/security/credentials/tls/grpc_tls_certificate_distributor.h"
-#include "src/core/lib/security/credentials/tls/grpc_tls_certificate_provider.h"
-#include "src/core/lib/security/credentials/tls/grpc_tls_certificate_verifier.h"
-#include "src/core/lib/security/security_connector/ssl_utils.h"
+#include "src/core/util/ref_counted.h"
+#include "src/core/credentials/transport/tls/grpc_tls_certificate_distributor.h"
+#include "src/core/credentials/transport/tls/grpc_tls_certificate_provider.h"
+#include "src/core/credentials/transport/tls/grpc_tls_certificate_verifier.h"
+#include "src/core/credentials/transport/tls/ssl_utils.h"
 
 // Contains configurable options specified by callers to configure their certain
 // security features supported in TLS.
@@ -337,9 +341,11 @@ for data_member in _DATA_MEMBERS:
         print(
             "  %s %s() const { return %s; }"
             % (
-                data_member.special_getter_return_type
-                if data_member.special_getter_return_type != ""
-                else data_member.type,
+                (
+                    data_member.special_getter_return_type
+                    if data_member.special_getter_return_type != ""
+                    else data_member.type
+                ),
                 data_member.name,
                 data_member.name + "_",
             ),
@@ -442,16 +448,14 @@ for data_member in _DATA_MEMBERS:
 print(
     """};
 
-#endif  // GRPC_SRC_CORE_LIB_SECURITY_CREDENTIALS_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H""",
+#endif  // GRPC_SRC_CORE_CREDENTIALS_TRANSPORT_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H""",
     file=H,
 )
 
 H.close()
 
-# Generate test/core/security/grpc_tls_credentials_options_comparator_test.cc
-TEST_FILE_NAME = (
-    "test/core/security/grpc_tls_credentials_options_comparator_test.cc"
-)
+# Generate test/core/credentials/transport/tls/grpc_tls_credentials_options_comparator_test.cc
+TEST_FILE_NAME = "test/core/credentials/transport/tls/grpc_tls_credentials_options_comparator_test.cc"
 test_file_name = TEST_FILE_NAME
 if test_mode:
     test_file_name = tempfile.NamedTemporaryFile(delete=False).name
@@ -468,12 +472,11 @@ print(
 
 #include <string>
 
-#include <gmock/gmock.h>
-
 #include <grpc/credentials.h>
 
-#include "src/core/lib/security/credentials/xds/xds_credentials.h"
-#include "src/core/lib/security/credentials/tls/grpc_tls_credentials_options.h"
+#include "gmock/gmock.h"
+#include "src/core/credentials/transport/xds/xds_credentials.h"
+#include "src/core/credentials/transport/tls/grpc_tls_credentials_options.h"
 #include "test/core/test_util/test_config.h"
 
 namespace grpc_core {
